@@ -6,11 +6,25 @@ use File::Basename;
 use File::Spec::Functions qw(splitdir catdir curdir catfile abs2rel);
 use Carp qw(croak carp confess);
 use Devel::InnerPackage;
-use vars qw($VERSION);
+use vars qw($VERSION $MR);
 
 use if $] > 5.017, 'deprecate';
 
-$VERSION = '5.0';
+$VERSION = '5.2';
+
+BEGIN {
+    eval {  require Module::Runtime };
+    unless ($@) {
+        Module::Runtime->import('require_module');
+    } else {
+        *require_module = sub {
+            my $module = shift;
+            my $path   = $module . ".pm";
+            $path =~ s{::}{/}g;
+            require $path;
+        };
+    }
+}
 
 
 sub new {
@@ -280,7 +294,7 @@ sub handle_finding_plugin {
     $self->{before_require}->($plugin) || return if defined $self->{before_require};
     unless ($no_req) {
         my $tmp = $@;
-        my $res = eval { $self->_require($plugin) };
+        my $res = eval { require_module($plugin) };
         my $err = $@;
         $@      = $tmp;
         if ($err) {
@@ -355,16 +369,6 @@ sub handle_innerpackages {
 
 }
 
-
-sub _require {
-    my $self   = shift;
-    my $pack   = shift;
-    eval "CORE::require $pack";
-    die ($@) if $@;
-    return 1;
-}
-
-
 1;
 
 =pod
